==> estateplat-common-1.2.4-20200108.024524-245-sources.jar: cn/gtmap/estateplat/model/information/core/XxJsydghxk.java <==
package cn.gtmap.estateplat.model.information.core;

import javax.persistence.Column;
import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2019-12-17
 * @description 建设用地规划许可证/规划方案模型
 */
@Table(name = "xx_jsydghxk")
public class XxJsydghxk extends XxMxParent implements InsertVo, XxMxVo {
    @Id
    private String ywid;//主键
    @Column
    private String proid;//项目表主键
    @Column
    private String yddw;//用地单位
    @Column
    private String ydxmmc;//用地项目名称
    @Column
    private String ydwz;//用地位置
    @Column
    private String ydxz;//用地性质
    @Column
    private Double ydmj;//用地面积
    @Column
    private String jsgm;//建设规模
    @Column
    private Date ghpzsj;//规划方案批准时间
    @Column
    private String bz; //备注
    @Column
    private String xxgxqk;//信息共享情况

    @Override
    public String getProid() {
        return proid;
    }

    @Override
    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getYddw() {
        return yddw;
    }

    public void setYddw(String yddw) {
        this.yddw = yddw;
    }

    public String getYdxmmc() {
        return ydxmmc;
    }

    public void setYdxmmc(String ydxmmc) {
        this.ydxmmc = ydxmmc;
    }

    public String getYdwz() {
        return ydwz;
    }

    public void setYdwz(String ydwz) {
        this.ydwz = ydwz;
    }

    public String getYdxz() {
        return ydxz;
    }

    public void setYdxz(String ydxz) {
        this.ydxz = ydxz;
    }

    public Double getYdmj() {
        return ydmj;
    }

    public void setYdmj(Double ydmj) {
        this.ydmj = ydmj;
    }

    public String getJsgm() {
        return jsgm;
    }

    public void setJsgm(String jsgm) {
        this.jsgm = jsgm;
    }

    public Date getGhpzsj() {
        return ghpzsj;
    }

    public void setGhpzsj(Date ghpzsj) {
        this.ghpzsj = ghpzsj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getXxgxqk() {
        return xxgxqk;
    }

    public void setXxgxqk(String xxgxqk) {
        this.xxgxqk = xxgxqk;
    }

    public String getYwid() {
        return ywid;
    }

    public void setYwid(String ywid) {
        this.ywid = ywid;
    }


    @Override
    public void setDwmc(String dwmc) {
        super.dwmc = "XXXX";
    }

    @Override
    public void setDwbm(String dwbm) {
        super.dwbm = "XXXX";
    }

    @Override
    public void setMxlx(String mxlx) {
        super.mxlx = "jsydghxk";
    }
}

==> estateplat-common-1.2.4-20200907.074136-427-sources.jar: cn/gtmap/estateplat/model/information/core/XxJsydghxk.java <==
package cn.gtmap.estateplat.model.information.core;

import javax.persistence.Column;
import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2019-12-17
 * @description 建设用地规划许可证/规划方案模型
 */
@Table(name = "xx_jsydghxk")
public class XxJsydghxk extends XxMxParent implements InsertVo, XxMxVo {
    @Id
    private String ywid;//主键
    @Column
    private String proid;//项目表主键
    @Column
    private String yddw;//用地单位
    @Column
    private String ydxmmc;//用地项目名称
    @Column
    private String ydwz;//用地位置
    @Column
    private String ydxz;//用地性质
    @Column
    private Double ydmj;//用地面积
    @Column
    private String jsgm;//建设规模
    @Column
    private Date ghpzsj;//规划方案批准时间
    @Column
    private String bz; //备注
    @Column
    private String xxgxqk;//信息共享情况
    @Column
    private String tjzt;//提交状态

    public String getTjzt() {
        return tjzt;
    }

    public void setTjzt(String tjzt) {
        this.tjzt = tjzt;
    }

    @Override
    public String getProid() {
        return proid;
    }

    @Override
    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getYddw() {
        return yddw;
    }

    public void setYddw(String yddw) {
        this.yddw = yddw;
    }

    public String getYdxmmc() {
        return ydxmmc;
    }

    public void setYdxmmc(String ydxmmc) {
        this.ydxmmc = ydxmmc;
    }

    public String getYdwz() {
        return ydwz;
    }

    public void setYdwz(String ydwz) {
        this.ydwz = ydwz;
    }

    public String getYdxz() {
        return ydxz;
    }

    public void setYdxz(String ydxz) {
        this.ydxz = ydxz;
    }

    public Double getYdmj() {
        return ydmj;
    }

    public void setYdmj(Double ydmj) {
        this.ydmj = ydmj;
    }

    public String getJsgm() {
        return jsgm;
    }

    public void setJsgm(String jsgm) {
        this.jsgm = jsgm;
    }

    public Date getGhpzsj() {
        return ghpzsj;
    }

    public void setGhpzsj(Date ghpzsj) {
        this.ghpzsj = ghpzsj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getXxgxqk() {
        return xxgxqk;
    }

    public void setXxgxqk(String xxgxqk) {
        this.xxgxqk = xxgxqk;
    }

    public String getYwid() {
        return ywid;
    }

    public void setYwid(String ywid) {
        this.ywid = ywid;
    }


    @Override
    public void setDwmc(String dwmc) {
        super.dwmc = "XXXX";
    }

    @Override
    public void setDwbm(String dwbm) {
        super.dwbm = "XXXX";
    }

    @Override
    public void setMxlx(String mxlx) {
        super.mxlx = "jsydghxk";
    }
}
